Server-side triggered DNS requests might be the intended behavior. It is recommended to review the purpose of the
service and evaluate the potential risks, like the participation in distributed denial of service (DDoS) attacks, and
interaction with remote services.

If this functionality is not the intended behavior, it is recommended to disable the service if possible or enforce
whitelist-based filtering blocking all unauthorized domains.
